QRCorrection class

QR Correction level

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

H → const QRCorrection
Level H: Recovery Capacity 30%
L → const QRCorrection
Level L: Recovery Capacity 7%
M → const QRCorrection
Level M: Recovery Capacity 15%
Q → const QRCorrection
Level Q: Recovery Capacity 25%