QRSize class

Constructors

QRSize(int value)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

size1 → const QRSize
size2 → const QRSize
size3 → const QRSize
size4 → const QRSize
size5 → const QRSize
size6 → const QRSize
size7 → const QRSize
size8 → const QRSize